%global cachedir %{_localstatedir}/cache/ddclient
%global rundir   %{_rundir}/ddclient

Summary:           Client to update dynamic DNS host entries
Name:              ddclient
Version:           3.11.2
Release:    1%{?dist}
License:           GPLv2+
URL:               https://ddclient.net/
Source0:           https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:           ddclient.rwtab
Source2:           ddclient.service
Source3:           ddclient.sysconfig
Source4:           ddclient.NetworkManager
Source5:           ddclient-tmpfiles.conf
Patch0:            skip-tests.patch

BuildArch:         noarch

BuildRequires:     autoconf
BuildRequires:     automake
BuildRequires:     make
BuildRequires:     perl-generators
BuildRequires:     perl(Sys::Hostname)
BuildRequires:     perl(version)
BuildRequires:     systemd
Requires(pre):     shadow-utils
Requires(post):    systemd
Requires(preun):   systemd
Requires(postun):  systemd

BuildRequires:     iproute
BuildRequires:     perl(HTTP::Daemon)
BuildRequires:     perl(HTTP::Daemon::SSL)
BuildRequires:     perl(HTTP::Message::PSGI)
BuildRequires:     perl(HTTP::Request)
BuildRequires:     perl(HTTP::Response)
BuildRequires:     perl(IO::Socket::INET6)
BuildRequires:     perl(Test::MockModule)
BuildRequires:     perl(Test::TCP)
BuildRequires:     perl(Test::Warnings)
BuildRequires:     perl(Time::HiRes)

Requires:          perl(Data::Validate::IP)
Requires:          perl(Digest::SHA1)
Requires:          perl(IO::Socket::INET6)
Requires:          perl(IO::Socket::SSL)
Requires:          perl(JSON::PP)

Conflicts:         NetworkManager < 1.20

%description
ddclient is a Perl client used to update dynamic DNS entries for accounts
on many different dynamic DNS services. Features include: Operating as a
daemon, manual and automatic updates, static and dynamic updates, optimized
updates for multiple addresses, MX, wildcards, abuse avoidance, retrying
the failed updates and sending update status to syslog and through e-mail.

%prep
%autosetup -p 1
sed -e 's|^mail=|#mail=|' -i ddclient.conf.in
./autogen


%configure \
 --runstatedir=%{rundir}

%build
make


%install
install -D -p -m 755 %{name} %{buildroot}%{_sbindir}/%{name}
install -D -p -m 600 ddclient.conf \
    %{buildroot}%{_sysconfdir}/%{name}.conf
install -D -p -m 644 %{SOURCE1} \
    %{buildroot}%{_sysconfdir}/rwtab.d/%{name}

install -D -p -m 644 %{SOURCE2} \
    %{buildroot}%{_unitdir}/%{name}.service
install -D -p -m 644 %{SOURCE3} \
    %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -D -p -m 755 %{SOURCE4} \
    %{buildroot}%{_prefix}/lib/NetworkManager/dispatcher.d/50-%{name}
install -D -p -m 644 %{SOURCE5} \
    %{buildroot}%{_tmpfilesdir}/%{name}.conf

mkdir -p %{buildroot}%{cachedir}
mkdir -p %{buildroot}%{rundir}
touch %{buildroot}%{cachedir}/%{name}.cache

chmod 644 sample-*


%check
make VERBOSE=1 check


%pre
getent group %{name} > /dev/null || %{_sbindir}/groupadd -r %{name}
getent passwd %{name} > /dev/null || %{_sbindir}/useradd -r -g %{name} -d %{_localstatedir}/cache/%{name} -s /sbin/nologin -c "Dynamic DNS Client" %{name}
exit 0

%post
%systemd_post %{name}.service
if [ $1 == 1 ]; then
    mkdir -p %{rundir}
    chown %{name}:%{name} %{rundir}
fi

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service


%files
%license COPYING COPYRIGHT
%doc README* ChangeLog.md sample-etc_ppp_ip-up.local
%doc sample-etc_dhclient-exit-hooks sample-etc_cron.d_ddclient
%doc sample-ddclient-wrapper.sh sample-etc_dhcpc_dhcpcd-eth0.exe

%{_sbindir}/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}.service

%config(noreplace) %{_sysconfdir}/rwtab.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(600,%{name},%{name}) %config(noreplace) %{_sysconfdir}/%{name}.conf
%{_prefix}/lib/NetworkManager/dispatcher.d/50-%{name}

%attr(0700,%{name},%{name}) %dir %{cachedir}
%attr(0600,%{name},%{name}) %ghost %{cachedir}/%{name}.cache
%ghost %attr(0755,%{name},%{name}) %dir %{rundir}


%changelog
* Wed Aug 14 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.11.2-1
- initial build
